@@ -13,9 +13,7 @@ macro_rules! hyper_response {
             .body(Body::from($message))
     };
     ($code: expr) => {
-        hyper::Response::builder()
-            .status($code)
-            .body(Body::from(""))
+        hyper::Response::builder().status($code).body(Body::empty())
     };
 }
 
@@ -61,7 +59,8 @@ impl HResultX for HResult {
                 HContent::Redirect(l) => Response::builder()
                     .status(StatusCode::MOVED_PERMANENTLY)
                     .header(hyper::header::LOCATION, l)
-                    .body(Body::from("")),
+                    .body(Body::empty()),
+                HContent::HyperResult(r) => r,
             },
             Err(e) if e.kind() == ErrorKind::ResourceNotFound => {
                 hyper_response!(StatusCode::NOT_FOUND, e.to_string())
@@ -83,6 +82,7 @@ pub enum HContent {
     Data(Vec<u8>, Option<&'static str>, Option<HeaderMap>),
     Value(Value),
     Redirect(String),
+    HyperResult(Result<Response<Body>, http::Error>),
 }
 
 impl HContent {
